"use client";

import Cookies from "js-cookie";
import { useParams } from "next/navigation";
import { ReactNode } from "react";

import {
	Select,
	SelectContent,
	SelectItem,
	SelectTrigger,
	SelectValue,
} from "@/components/ui/select";
import { Locale, routing, usePathname, useRouter } from "@/i18n/routing";

type Props = {
	children: ReactNode;
	defaultValue: string;
	label: string;
};

export default function LanguageSwitcherSelect({ defaultValue, label }: Props) {
	const router = useRouter();

	const pathname = usePathname();
	const params = useParams();

	function onSelectChange(nextLocale: string) {
		Cookies.set("NEXT_LOCALE", nextLocale, { expires: 1 });
		router.replace(
			// @ts-expect-error -- TypeScript will validate that only known `params`
			// are used in combination with a given `pathname`. Since the two will
			// always match for the current route, we can skip runtime checks.
			{ pathname, params },
			{ locale: nextLocale as Locale }
		);
	}

	return (
		<Select defaultValue={defaultValue} onValueChange={onSelectChange}>
			<SelectTrigger
				className="border-none bg-transparent text-white shadow-none focus:ring-0 focus:ring-offset-0"
				aria-label={label}
			>
				<SelectValue />
			</SelectTrigger>
			<SelectContent>
				{routing.locales?.map((locale) => (
					<SelectItem key={locale} value={locale}>
						{locale === "en" ? "English" : "العربية"}
					</SelectItem>
				))}
			</SelectContent>
			<style jsx>{`
        :global(.select-trigger .lucide-chevron-down) {
          color: white;
          fill: white;
          width: 20px;
          height: 20px;
        }
      `}</style>
		</Select>
	);
}
